import { LarkAction, LarkEvent } from "../types";
declare class LarkBody {
    protected body: LarkEvent.Data | LarkAction.Data;
    /**
     * 是否为Lark消息体
     */
    isLarkBody: boolean;
    /**
     * 是否为事件消息
     */
    isEvent: boolean;
    /**
     * 是否为Action消息
     */
    isAction: boolean;
    /**
     * 事件类型
     */
    eventType?: LarkEvent.Data["header"]["event_type"];
    /**
     * 是否为消息事件
     */
    isMessageEvent?: boolean;
    /**
     * 消息类型
     */
    msgType?: LarkEvent.Message["message_type"];
    /**
     * 用户Id
     */
    userId?: LarkEvent.UserIdInfo["user_id"];
    /**
     * 用户OpenId
     */
    openId?: LarkEvent.UserIdInfo["open_id"];
    /**
     * 文本内容
     */
    msgText: string;
    /**
     * 原始文本内容
     */
    rawMsgText: string;
    /**
     * 聊天类型
     */
    chatType?: LarkEvent.Message["chat_type"];
    /**
     * 是否为P2P聊天
     */
    isP2P?: boolean;
    /**
     * 是否在群聊中
     */
    isInGroup?: boolean;
    /**
     * 艾特信息
     */
    mentions?: LarkEvent.Mention[];
    /**
     * 艾特的机器人
     */
    mentionedRobot?: LarkEvent.Mention;
    /**
     * Action类型
     */
    actionType?: LarkAction.Data["action"]["tag"];
    /**
     * Action参数
     */
    actionValue?: LarkAction.Data["action"]["value"];
    /**
     * Action选项
     */
    actionOption?: LarkAction.Data["action"]["option"];
    /**
     * 对话流Id
     */
    chatId: LarkEvent.Message["chat_id"] | LarkAction.Data["open_chat_id"];
    /**
     * 消息Id
     */
    messageId: LarkEvent.Message["message_id"] | LarkAction.Data["open_message_id"];
    /**
     * 构造函数
     * @param body 事件消息体或Action消息体
     */
    constructor(body: LarkEvent.Data | LarkAction.Data);
    /**
     * 获取事件类型
     * @param body 事件消息体
     * @returns 事件类型
     */
    private getEventType;
    /**
     * 是否为消息事件
     * @param body 消息事件体
     * @returns
     */
    private getIsMessageEvent;
    /**
     * 是否为事件消息
     * @param body 事件消息体
     * @returns 是否为事件消息
     */
    private getIsEvent;
    /**
     * 是否为Action消息
     * @param body Action消息体
     * @returns 是否为Action消息
     */
    private getIsAction;
    /**
     * 获取事件文本类型
     * @param body 事件消息体
     * @returns 事件文本类型
     */
    private getMsgType;
    /**
     * 获取文本内容并剔除艾特信息
     * @param body 事件消息体
     * @returns 文本内容
     */
    private getMsgText;
    /**
     * 获取原始文本内容
     * @param body 事件消息体
     * @returns 原始文本内容
     */
    private getRawMsgText;
    /**
     * 获取聊天类型
     * @param body 事件消息体
     * @returns 聊天类型
     */
    private getChatType;
    /**
     * 获取艾特信息
     * @param body 事件消息体
     * @returns 艾特信息
     */
    private getMentions;
    /**
     * 获取艾特的机器人
     * @param body 事件消息体
     * @returns 艾特的机器人
     */
    private getMentionedRobot;
    /**
     * 获取Action类型
     * @param body Action消息体
     * @returns Action类型
     */
    private getActionType;
    /**
     * 获取Action参数
     * @param body Action消息体
     * @returns Action参数
     */
    private getActionValue;
    /**
     * 获取Action选项
     * @param body Action消息体
     * @returns Action选项
     */
    private getActionOption;
    /**
     * 获取对话流Id
     * @param body 事件消息体或Action消息体
     * @returns 对话流Id
     */
    private getChatId;
    /**
     * 获取消息Id
     * @param body 事件消息体或Action消息体
     * @returns 消息Id
     */
    private getMessageId;
    /**
     * 获取用户Id
     * @param body 事件消息体
     * @returns 用户Id
     */
    private getUserId;
    /**
     * 获取用户OpenId
     * @param body 事件消息体
     * @returns 用户OpenId
     */
    private getOpenId;
    /**
     * 是否艾特了机器人
     * @param name 机器人名字
     * @returns 是否艾特了机器人
     */
    isAtBot(name: string): boolean;
}
export default LarkBody;
