import _, { isObject } from "lodash";
import { baseErrorCard, basePendingCard, baseSuccessCard } from "./component";
class LarkCard {
    requestId;
    funcName;
    functionMap;
    cardMap;
    tempMap;
    stringify;
    logger;
    constructor({ funcName, stringify = false, requestId, cardMap = {}, tempMap = {}, functionMap = {}, logger, }) {
        this.stringify = stringify;
        this.requestId = requestId;
        this.funcName = funcName;
        this.functionMap = functionMap;
        this.cardMap = {
            success: baseSuccessCard,
            error: baseErrorCard,
            pending: basePendingCard,
            ...cardMap,
        };
        this.tempMap = tempMap;
        this.logger = logger;
    }
    setFunction(funcName) {
        this.funcName = funcName;
    }
    setStringify(stringify) {
        this.stringify = stringify;
    }
    child(func, stringify) {
        return new LarkCard({
            funcName: func,
            stringify: stringify || this.stringify,
            requestId: this.requestId,
            cardMap: this.cardMap,
            tempMap: this.tempMap,
            functionMap: this.functionMap,
            logger: this.logger,
        });
    }
    genCard(cardKey, variables) {
        const card = isObject(cardKey) ? cardKey : this.cardMap[cardKey];
        if (!card) {
            this.logger.error("卡片未找到", {
                cardKey: String(cardKey),
            });
            throw new Error(`Card ${String(cardKey)} not found`);
        }
        const finalVariables = {
            ...variables,
            requestId: this.requestId,
            ...this.functionMap[this.funcName],
        };
        this.logger.debug("卡片最终变量", {
            cardKey: String(cardKey),
            variables: finalVariables,
        });
        const replaceVariables = (str) => {
            const variablePattern = /\$\{(\w+)\}/g;
            const matches = str.match(variablePattern);
            if (matches && matches.length === 1 && matches[0] === str) {
                const variableName = matches[0].slice(2, -1);
                return finalVariables[variableName] || "";
            }
            else {
                return str.replace(variablePattern, (_, v) => finalVariables[v] || "");
            }
        };
        const traverseAndReplace = (obj) => {
            if (_.isString(obj)) {
                return replaceVariables(obj);
            }
            else if (_.isArray(obj)) {
                return obj.map(traverseAndReplace);
            }
            else if (_.isObject(obj)) {
                return _.mapValues(obj, traverseAndReplace);
            }
            return obj;
        };
        const content = traverseAndReplace(card);
        // 递归遍历content，遇到key是"value"的Object，将variables注入
        const injectVariables = (obj) => {
            if (_.isObject(obj) && !_.isArray(obj)) {
                if (_.has(obj, "value") && _.isObject(obj.value)) {
                    return {
                        ...obj,
                        value: { ...obj.value, ...finalVariables },
                    };
                }
                return _.mapValues(obj, injectVariables);
            }
            else if (_.isArray(obj)) {
                return obj.map(injectVariables);
            }
            return obj;
        };
        const finalContent = injectVariables(content);
        this.logger.debug("卡片最终内容", {
            cardKey: String(cardKey),
            content: finalContent,
        });
        return this.stringify ? JSON.stringify(finalContent) : finalContent;
    }
    genSuccessCard(content) {
        return this.genCard("success", { content });
    }
    genErrorCard(content) {
        return this.genCard("error", { content });
    }
    genPendingCard(content) {
        return this.genCard("pending", { content });
    }
    genTempCard(tempKey, variables) {
        const tempId = this.tempMap[tempKey];
        if (!tempId) {
            this.logger.error("模板未找到", {
                tempKey: String(tempKey),
            });
            throw new Error(`Temp ${String(tempKey)} not found`);
        }
        const finalVariables = {
            ...variables,
            requestId: this.requestId,
            ...this.functionMap[this.funcName],
        };
        this.logger.debug("模板最终变量", {
            tempKey: String(tempKey),
            variables: finalVariables,
        });
        const content = {
            type: "template",
            data: {
                config: {
                    update_multi: true,
                    enable_forward: false,
                },
                template_id: tempId,
                template_variable: finalVariables,
            },
        };
        this.logger.debug("模板最终内容", {
            tempKey: String(tempKey),
            content,
        });
        return this.stringify ? JSON.stringify(content) : content;
    }
}
export default LarkCard;
//# sourceMappingURL=index.js.map